/// <reference types="react" />
import { ComponentEnhancer } from 'recompose';
/**
 * Given an error from yup validation, turn it into form errors
 */
export declare function yupToFormErrors(yupError: any): FormikErrors;
/**
 * Given a FormState, return a `touched` value with all of the fields touched.
 */
export declare function touchAllFields<T>(fields: T): {
    [field: string]: boolean;
};
export declare function validateFormData<T>(data: T, schema: any, setErrors: (errors: FormikErrors) => void): Promise<boolean>;
export interface FormikConfig<Props, FormState, Payload> {
    displayName: string;
    mapPropsToFormState?: (props: Props) => FormState;
    mapFormStateToPayload?: (formState: FormState) => Payload;
    validationSchema: any;
    handleSubmit: (payload: Payload) => void;
}
export interface FormikState<T> {
    form?: T;
    /** map of field names to specific error for that field */
    errors: FormikErrors;
    /** map of field names to whether the field has been touched */
    touched: FormikTouched;
    /** whether the form is currently submitting */
    isSubmitting: boolean;
}
export interface InjectedFormikProps {
    /** map of field names to specific error for that field */
    errors: FormikErrors;
    /** map of field names to whether the field has been touched */
    touched: FormikTouched;
    /** whether the form is currently submitting */
    isSubmitting: boolean;
    onSubmit: (e: React.FormEvent<HTMLFormElement>) => void;
    onChange: (e: React.ChangeEvent<any>) => void;
}
export interface FormikErrors {
    [field: string]: string;
}
export interface FormikTouched {
    [field: string]: boolean;
}
export default function Formik<Props, State, Payload>({displayName, mapPropsToFormState, mapFormStateToPayload, validationSchema, handleSubmit}: FormikConfig<Props, State, Payload>): ComponentEnhancer<{}, Props>;
